package goblint

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Goblint_lib.MustlockHistory

must-lock history analysis mustlockHistory collects for locks, in which threads a lock operation must have happened before reaching the current program point.

@see https://github.com/goblint/analyzer/pull/1923

module TIDs : sig ... end
module Lock = LockDomain.MustLock
module Spec : sig ... end